@@ -19,7 +19,8 @@ def create_devops_terraform_build_config(stage,
                                          build_commons_path=None,
                                          terraform_build_commons_dir_name='terraform',
                                          debug_print_terraform_command=False,
-                                         additional_tfvar_files=[]):
+                                         additional_tfvar_files=[],
+                                         terraform_version=0.15):
     ret = create_devops_build_config(
         stage, project_root_path, module, build_dir_name)
     ret.update({'additional_vars': additional_vars,
@@ -29,7 +30,8 @@ def create_devops_terraform_build_config(stage,
                 'build_commons_path': build_commons_path,
                 'terraform_build_commons_dir_name': terraform_build_commons_dir_name,
                 'debug_print_terraform_command': debug_print_terraform_command,
-                'additional_tfvar_files': additional_tfvar_files})
+                'additional_tfvar_files': additional_tfvar_files,
+                'terraform_version': terraform_version})
     return ret
 
 class DevopsTerraformBuild(DevopsBuild):
@@ -45,6 +47,7 @@ class DevopsTerraformBuild(DevopsBuild):
         self.terraform_build_commons_dir_name = config['terraform_build_commons_dir_name']
         self.debug_print_terraform_command = config['debug_print_terraform_command']
         self.additional_tfvar_files = config['additional_tfvar_files']
+        self.terraform_version = config['terraform_version']
 
     def terraform_build_commons_path(self):
         mylist = [self.build_commons_path,
@@ -111,7 +114,7 @@ class DevopsTerraformBuild(DevopsBuild):
         result = tf.output(json=IsFlagged)
         self.print_terraform_command(tf)
         with open(self.build_path() + self.output_json_name, "w") as output_file:
-            output_file.write(json.dumps(result))
+            output_file.write(dumps(result))
 
     def read_output_json(self):
         with open(self.build_path() + self.output_json_name, 'r') as f:
@@ -141,10 +144,20 @@ class DevopsTerraformBuild(DevopsBuild):
 
     def apply(self, auto_approve=False):
         tf = self.init_client()
-        return_code, stdout, stderr = tf.apply(capture_output=False, raise_on_error=True,
-                 skip_plan=auto_approve,
-                 var=self.project_vars(),
-                 var_file=self.additional_tfvar_files)
+        if auto_approve:
+            auto_approve_flag = IsFlagged
+        else:
+            auto_approve_flag = None
+        if self.terraform_version >= 1.0:
+            return_code, stdout, stderr = tf.apply(capture_output=False, raise_on_error=True,
+                    auto_approve=auto_approve_flag,
+                    var=self.project_vars(),
+                    var_file=self.additional_tfvar_files)
+        else:
+            return_code, stdout, stderr = tf.apply(capture_output=False, raise_on_error=True,
+                    skip_plan=auto_approve,
+                    var=self.project_vars(),
+                    var_file=self.additional_tfvar_files)
         self.write_output(tf)
         self.post_build()
         self.print_terraform_command(tf)
@@ -165,13 +178,19 @@ class DevopsTerraformBuild(DevopsBuild):
     def destroy(self, auto_approve=False):
         tf = self.init_client()
         if auto_approve:
-            force = IsFlagged
+            auto_approve_flag = IsFlagged
         else:
-            force = None
-        return_code, stdout, stderr = tf.destroy(capture_output=False, raise_on_error=True,
-                   force=force,
-                   var=self.project_vars(),
-                   var_file=self.additional_tfvar_files)
+            auto_approve_flag = None
+        if self.terraform_version >= 1.0:
+            return_code, stdout, stderr = tf.destroy(capture_output=False, raise_on_error=True,
+                    auto_approve=auto_approve_flag,
+                    var=self.project_vars(),
+                    var_file=self.additional_tfvar_files)
+        else:
+            return_code, stdout, stderr = tf.destroy(capture_output=False, raise_on_error=True,
+                    force=auto_approve_flag,
+                    var=self.project_vars(),
+                    var_file=self.additional_tfvar_files)
         self.post_build()
         self.print_terraform_command(tf)
         if (return_code > 0):
@@ -190,5 +209,5 @@ class DevopsTerraformBuild(DevopsBuild):
 
     def print_terraform_command(self, tf):
         if self.debug_print_terraform_command:
-            output = 'cd ' + self.build_path() + ' && ' + tf.latest_cmd
+            output = 'cd ' + self.build_path() + ' && ' + tf.latest_cmd()
             print(output)
